@@ -13,7 +13,7 @@ use File::Path  qw[mkpath rmtree];
 use File::pushd qw[pushd];
 use vars        qw[$VERSION];
 
-$VERSION = '0.18';
+$VERSION = '0.20';
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -68,6 +68,12 @@ has 'noclean' => (
   default => 0,
 );
 
+has 'nozapman' => (
+  is => 'ro',
+  isa => 'Bool',
+  default => 0,
+);
+
 has 'make' => (
   is => 'ro',
   isa => 'Str',
@@ -111,6 +117,8 @@ sub build_perl {
       return unless scalar run( command => [ $self->make, 'test' ], verbose => $self->verbose );
     }
     return unless scalar run( command => [ $self->make, 'install' ], verbose => $self->verbose );
+    rmtree ( File::Spec->catdir( $prefix, 'man' ) ) # remove the manpages
+      unless $self->nozapman;
   }
   rmtree( $extract ) unless $self->noclean();
   return $prefix;
@@ -219,11 +227,21 @@ Optional boolean attribute, which defaults to 0, indicates whether we should pro
 Optional boolean attribute, which defaults to 0, indicates whether we should cleanup files that we
 produce under the C<builddir> or not.
 
+=item C<nozapman>
+
+This is an optional boolean attribute. Usually C<man> pages that are generated by the perl installation are removed.
+Specify this option if you wish the C<man> pages to be retained.
+
 =item C<make>
 
 Optional attribute to specify the C<make> utility to use. Defaults to C<make> and you should only have to
 mess with this on wacky platforms.
 
+=item C<mirrors>
+
+This is an optional argument. Specify the URL of a CPAN mirror that should be used for retrieving required files
+during the build process. This may be a single URL or an arrayref of a number of URLs.
+
 =back
 
 =back
